==> pedbarrayv9.db_2.0.2.tar.gz: pedbarrayv9.db/man/pedbarrayv9_dbconn.Rd <==
\name{pedbarrayv9_dbconn}

\alias{pedbarrayv9_dbconn}
\alias{pedbarrayv9_dbfile}
\alias{pedbarrayv9_dbschema}
\alias{pedbarrayv9_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  pedbarrayv9_dbconn()
  pedbarrayv9_dbfile()
  pedbarrayv9_dbschema(file="", show.indices=FALSE)
  pedbarrayv9_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{pedbarrayv9_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{pedbarrayv9_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{pedbarrayv9_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{pedbarrayv9_dbschema} prints the schema definition of the
  package annotation DB.

  \code{pedbarrayv9_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{pedbarrayv9_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{pedbarrayv9_dbfile}: a character string with the path to the
  package annotation DB.

  \code{pedbarrayv9_dbschema}: none (invisible \code{NULL}).

  \code{pedbarrayv9_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(pedbarrayv9_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by pedbarrayv9_dbconn() was created with:
  dbConnect(SQLite(), dbname=pedbarrayv9_dbfile(), cache_size=64000, synchronous=0)

  pedbarrayv9_dbschema()

  pedbarrayv9_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

==> pedbarrayv9.db_2.14.0.tar.gz: pedbarrayv9.db/man/pedbarrayv9_dbconn.Rd <==

\name{pedbarrayv9_dbconn}

\alias{pedbarrayv9_dbconn}
\alias{pedbarrayv9_dbfile}
\alias{pedbarrayv9_dbschema}
\alias{pedbarrayv9_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  pedbarrayv9_dbconn()
  pedbarrayv9_dbfile()
  pedbarrayv9_dbschema(file="", show.indices=FALSE)
  pedbarrayv9_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{pedbarrayv9_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{pedbarrayv9_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{pedbarrayv9_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{pedbarrayv9_dbschema} prints the schema definition of the
  package annotation DB.

  \code{pedbarrayv9_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{pedbarrayv9_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{pedbarrayv9_dbfile}: a character string with the path to the
  package annotation DB.

  \code{pedbarrayv9_dbschema}: none (invisible \code{NULL}).

  \code{pedbarrayv9_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(pedbarrayv9_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by pedbarrayv9_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=pedbarrayv9_dbfile(), cache_size=64000,
  synchronous=0)

  pedbarrayv9_dbschema()

  pedbarrayv9_dbInfo()
}

\keyword{utilities}
\keyword{datasets}
